.. include:: overall.md
   :parser: myst_parser.sphinx_

Table of contents
=================
.. toctree::
   :maxdepth: 2
   :caption: Guides

   guide/index

.. toctree::
   :maxdepth: 2
   :caption: Tutorials

   tutorial/index

.. toctree::
   :maxdepth: 2
   :caption: Developing

   develop
   
.. toctree::
   :maxdepth: 2
   :caption: External resources

   external

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`